==> django-fiber-0.9.2.tar.gz: django-fiber-0.9.2/fiber/static/fiber/js/markitup-1.1.10/sets/textile_fiber/set.js <==
// -------------------------------------------------------------------
// markItUp!
// -------------------------------------------------------------------
// Copyright (C) 2008 Jay Salvat
// http://markitup.jaysalvat.com/
// -------------------------------------------------------------------
// Textile tags example
// http://en.wikipedia.org/wiki/Textile_(markup_language)
// http://www.textism.com/
// -------------------------------------------------------------------
// Feel free to add more tags
// -------------------------------------------------------------------

// Changed mySettings into markitup_settings
markitup_settings = {
	onShiftEnter: {keepDefault:false, replaceWith:'\n\n'},
	markupSet: [
		{name:'Heading 1', key:'1', openWith:'h1(!(([![Class]!]))!). ', placeHolder:'Your title here...' },
		{name:'Heading 2', key:'2', openWith:'h2(!(([![Class]!]))!). ', placeHolder:'Your title here...' },
		{name:'Heading 3', key:'3', openWith:'h3(!(([![Class]!]))!). ', placeHolder:'Your title here...' },
		{name:'Paragraph', key:'P', openWith:'p(!(([![Class]!]))!). '},
		{separator:'---------------' },
		{name:'Bold', key:'B', closeWith:'*', openWith:'*'},
		{name:'Italic', key:'I', closeWith:'_', openWith:'_'},
		{separator:'---------------' },
		{name:'Bulleted list', openWith:'(!(* |!|*)!)'},
		{name:'Numeric list', openWith:'(!(# |!|#)!)'},
		{separator:'---------------' },
		{name:'Link To A Page In This Site', className: 'select_page', placeHolder: 'page'},
		{name:'Link To A File In This Site', className: 'select_file'},
		{name:'Link To An Image In This Site', className: 'select_link_to_image'},
		{name:'Custom Link', openWith:'"', closeWith:'":[![Link:!:http://]!]', placeHolder: 'link' },
		{separator:'---------------' },
		{name:'Image', className: 'select_image'},
	]
}

==> django-fiber-0.9.4.4.tar.gz: django-fiber-0.9.4.4/fiber/static/fiber/js/markitup-1.1.10/sets/textile_fiber/set.js <==
// -------------------------------------------------------------------
// markItUp!
// -------------------------------------------------------------------
// Copyright (C) 2008 Jay Salvat
// http://markitup.jaysalvat.com/
// -------------------------------------------------------------------
// Textile tags example
// http://en.wikipedia.org/wiki/Textile_(markup_language)
// http://www.textism.com/
// -------------------------------------------------------------------
// Feel free to add more tags
// -------------------------------------------------------------------

// Changed mySettings into markitup_settings
markitup_settings = {
	onShiftEnter: {keepDefault:false, replaceWith:'\n\n'},
	markupSet: [
		{name:'Heading 1', key:'1', openWith:'h1(!(([![Class]!]))!). ', placeHolder:'Your title here...' },
		{name:'Heading 2', key:'2', openWith:'h2(!(([![Class]!]))!). ', placeHolder:'Your title here...' },
		{name:'Heading 3', key:'3', openWith:'h3(!(([![Class]!]))!). ', placeHolder:'Your title here...' },
		{name:'Paragraph', key:'P', openWith:'p(!(([![Class]!]))!). '},
		{separator:'---------------' },
		{name:'Bold', key:'B', closeWith:'*', openWith:'*'},
		{name:'Italic', key:'I', closeWith:'_', openWith:'_'},
		{separator:'---------------' },
		{name:'Bulleted list', openWith:'(!(* |!|*)!)'},
		{name:'Numeric list', openWith:'(!(# |!|#)!)'},
		{separator:'---------------' },
		{name:'Link To A Page In This Site', className: 'select_page'},
		{name:'Link To A File In This Site', className: 'select_file'},
		{name:'Link To An Image In This Site', className: 'select_link_to_image'},
		{name:'Custom Link', openWith:'"', closeWith:'":[![Link:!:http://]!]', placeHolder: 'link' },
		{separator:'---------------' },
		{name:'Image', className: 'select_image'},
	]
}
